%define anolis_release 1

Summary: SELinux binary policy manipulation library
Name: libsemanage
Version: 3.5
Release: %{anolis_release}%{?dist}
License: LGPLv2+
Source0: https://github.com/SELinuxProject/selinux/releases/download/%{version}/%{name}-%{version}.tar.gz
URL: https://github.com/SELinuxProject/selinux/wiki
Source1: semanage.conf

BuildRequires: gcc make swig
BuildRequires: libselinux-devel >= %{version}
BuildRequires: libsepol-devel >= %{version} 
BuildRequires: audit-libs-devel
BuildRequires: bison flex bzip2-devel

BuildRequires: python3
BuildRequires: python3-devel

Requires: bzip2-libs audit-libs
Requires: libselinux >= %{version}
Obsoletes: libsemanage-compat = 3.1

%description
Security-enhanced Linux is a feature of the Linux® kernel and a number
of utilities with enhanced security functionality designed to add
mandatory access controls to Linux.  The Security-enhanced Linux
kernel contains new architectural components originally developed to
improve the security of the Flask operating system. These
architectural components provide general support for the enforcement
of many kinds of mandatory access control policies, including those
based on the concepts of Type Enforcement®, Role-based Access
Control, and Multi-level Security.

libsemanage provides an API for the manipulation of SELinux binary policies.
It is used by checkpolicy (the policy compiler) and similar tools, as well
as by programs like load_policy that need to perform specific transformations
on binary policies such as customizing policy boolean settings.

%package static
Summary: Static library used to build policy manipulation tools
Requires: libsemanage-devel = %{version}-%{release}

%description static
The semanage-static package contains the static libraries 
needed for developing applications that manipulate binary policies. 

%package devel
Summary: Header files and libraries used to build policy manipulation tools
Requires: %{name} = %{version}-%{release}

%description devel
The semanage-devel package contains the libraries and header files
needed for developing applications that manipulate binary policies. 

%package -n python3-libsemanage
Summary: semanage python 3 bindings for libsemanage
Requires: %{name} = %{version}-%{release}
Requires: libselinux-python3
%{?python_provide:%python_provide python3-libsemanage}
Provides: %{name}-python3 = %{version}-%{release}
Obsoletes: %{name}-python3 < %{version}-%{release}

%description -n python3-libsemanage
The libsemanage-python3 package contains the python 3 bindings for developing
SELinux management applications.

%package doc
Summary:        Documentation files for %{name}
Requires:       %{name} = %{version}-%{release}
BuildArch:      noarch

%description    doc
The %{name}-doc package contains documentation files for %{name}.

%prep
%autosetup -n libsemanage-%{version} -p 2


%build
%set_build_flags
CFLAGS="$CFLAGS -fno-semantic-interposition"

# To support building the Python wrapper against multiple Python runtimes
# Define a function, for how to perform a "build" of the python wrapper against
# a specific runtime:
BuildPythonWrapper() {
  BinaryName=$1

  # Perform the build from the upstream Makefile:
  make \
    PYTHON=$BinaryName \
    LIBDIR="%{_libdir}" SHLIBDIR="%{_lib}" \
    pywrap
}

make clean
make swigify
%make_build LIBDIR="%{_libdir}" SHLIBDIR="%{_lib}" all

BuildPythonWrapper \
  %{__python3}

%install
InstallPythonWrapper() {
  BinaryName=$1

  make \
    PYTHON=$BinaryName \
    DESTDIR="${RPM_BUILD_ROOT}" LIBDIR="%{_libdir}" SHLIBDIR="%{_libdir}" \
    install-pywrap
}

mkdir -p ${RPM_BUILD_ROOT}%{_libdir}
mkdir -p ${RPM_BUILD_ROOT}%{_includedir} 
mkdir -p ${RPM_BUILD_ROOT}%{_sharedstatedir}/selinux
mkdir -p ${RPM_BUILD_ROOT}%{_sharedstatedir}/selinux/tmp
%make_install LIBDIR="%{_libdir}" SHLIBDIR="%{_libdir}"

InstallPythonWrapper \
  %{__python3} \
  $(python3-config --extension-suffix)
  
cp %{SOURCE1} ${RPM_BUILD_ROOT}%{_sysconfdir}/selinux/semanage.conf

%generate_compatibility_deps

%files
%dir %{abidir}
%license LICENSE
%dir %{_sysconfdir}/selinux
%config(noreplace) %{_sysconfdir}/selinux/semanage.conf
%{_libdir}/libsemanage.so.2
%{_mandir}/man5/*
%lang(ru) %{_mandir}/ru/man5/*
%dir %{_libexecdir}/selinux
%dir %{_sharedstatedir}/selinux
%dir %{_sharedstatedir}/selinux/tmp
%{abidir}/libsemanage.dump

%files static
%{_libdir}/libsemanage.a

%files devel
%{_libdir}/libsemanage.so
%{_libdir}/pkgconfig/libsemanage.pc
%dir %{_includedir}/semanage
%{_includedir}/semanage/*.h
%{_mandir}/man3/*

%files -n python3-libsemanage
%{abidir}/_semanage.*.dump
%{python3_sitearch}/*.so
%{python3_sitearch}/semanage.py*
%{python3_sitearch}/__pycache__/semanage*
%{_libexecdir}/selinux/semanage_migrate_store

%files doc
%doc VERSION

%changelog
* Wed Mar 01 2023 Funda Wang <fundawang@yeah.net> - 3.5-1
- New version 3.5

* Tue Jan 10 2023 yuanhui <yuanhui@linux.alibaba.com> - 3.4-3
- add doc package

* Thu Oct 20 2022 mgb01105731 <mgb01105731@alibaba-inc.com> - 3.4-2
- optimise spec file

* Mon Sep 26 2022 mgb01105731 <mgb01105731@alibaba-inc.com> - 3.4-1
- update to 3.4

* Wed Mar 09 2022 Chunmei Xu <xuchunmei@linux.alibaba.com> - 3.3-1
- init from upstream 3.3
